==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/ConnectToTargetAzureDbForMySqlTaskPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import com.pulumi.core.Either
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Properties for the task that validates connection to Azure Database for MySQL and target server requirements
 * @property clientData Key value pairs of client data to attach meta data information to task
 * @property commands Array of command properties.
 * @property errors Array of errors. This is ignored if submitted.
 * @property input Task input
 * @property output Task output. This is ignored if submitted.
 * @property state The state of the task. This is ignored if submitted.
 * @property taskType Task type.
 * Expected value is 'ConnectToTarget.AzureDbForMySql'.
 */
public data class ConnectToTargetAzureDbForMySqlTaskPropertiesResponse(
    public val clientData: Map<String, String>? = null,
    public val commands:
    List<Either<MigrateMISyncCompleteCommandPropertiesResponse, MigrateSyncCompleteCommandPropertiesResponse>>,
    public val errors: List<ODataErrorResponse>,
    public val input: ConnectToTargetAzureDbForMySqlTaskInputResponse? = null,
    public val output: List<ConnectToTargetAzureDbForMySqlTaskOutputResponse>,
    public val state: String,
    public val taskType: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.ConnectToTargetAzureDbForMySqlTaskPropertiesResponse):
            ConnectToTargetAzureDbForMySqlTaskPropertiesResponse =
            ConnectToTargetAzureDbForMySqlTaskPropertiesResponse(
                clientData = javaType.clientData().map({ args0 -> args0.key.to(args0.value) }).toMap(),
                commands = javaType.commands().map({ args0 ->
                    args0.transform(
                        { args0 ->
                            args0.let({ args0 ->
                                com.pulumi.azurenative.datamigration.kotlin.outputs.MigrateMISyncCompleteCommandPropertiesResponse.Companion.toKotlin(args0)
                            })
                        },
                        { args0 ->
                            args0.let({ args0 ->
                                com.pulumi.azurenative.datamigration.kotlin.outputs.MigrateSyncCompleteCommandPropertiesResponse.Companion.toKotlin(args0)
                            })
                        },
                    )
                }),
                errors = javaType.errors().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.datamigration.kotlin.outputs.ODataErrorResponse.Companion.toKotlin(args0)
                    })
                }),
                input = javaType.input().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.datamigration.kotlin.outputs.ConnectToTargetAzureDbForMySqlTaskInputResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                output = javaType.output().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.datamigration.kotlin.outputs.ConnectToTargetAzureDbForMySqlTaskOutputResponse.Companion.toKotlin(args0)
                    })
                }),
                state = javaType.state(),
                taskType = javaType.taskType(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/ConnectToTargetAzureDbForMySqlTaskPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import com.pulumi.core.Either
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Properties for the task that validates connection to Azure Database for MySQL and target server requirements
 * @property clientData Key value pairs of client data to attach meta data information to task
 * @property commands Array of command properties.
 * @property errors Array of errors. This is ignored if submitted.
 * @property input Task input
 * @property output Task output. This is ignored if submitted.
 * @property state The state of the task. This is ignored if submitted.
 * @property taskType Task type.
 * Expected value is 'ConnectToTarget.AzureDbForMySql'.
 */
public data class ConnectToTargetAzureDbForMySqlTaskPropertiesResponse(
    public val clientData: Map<String, String>? = null,
    public val commands: List<Either<MigrateMISyncCompleteCommandPropertiesResponse, MigrateSyncCompleteCommandPropertiesResponse>>,
    public val errors: List<ODataErrorResponse>,
    public val input: ConnectToTargetAzureDbForMySqlTaskInputResponse? = null,
    public val output: List<ConnectToTargetAzureDbForMySqlTaskOutputResponse>,
    public val state: String,
    public val taskType: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.ConnectToTargetAzureDbForMySqlTaskPropertiesResponse): ConnectToTargetAzureDbForMySqlTaskPropertiesResponse =
            ConnectToTargetAzureDbForMySqlTaskPropertiesResponse(
                clientData = javaType.clientData().map({ args0 -> args0.key.to(args0.value) }).toMap(),
                commands = javaType.commands().map({ args0 ->
                    args0.transform(
                        { args0 ->
                            args0.let({ args0 ->
                                com.pulumi.azurenative.datamigration.kotlin.outputs.MigrateMISyncCompleteCommandPropertiesResponse.Companion.toKotlin(args0)
                            })
                        },
                        { args0 ->
                            args0.let({ args0 ->
                                com.pulumi.azurenative.datamigration.kotlin.outputs.MigrateSyncCompleteCommandPropertiesResponse.Companion.toKotlin(args0)
                            })
                        },
                    )
                }),
                errors = javaType.errors().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.datamigration.kotlin.outputs.ODataErrorResponse.Companion.toKotlin(args0)
                    })
                }),
                input = javaType.input().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.datamigration.kotlin.outputs.ConnectToTargetAzureDbForMySqlTaskInputResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                output = javaType.output().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.datamigration.kotlin.outputs.ConnectToTargetAzureDbForMySqlTaskOutputResponse.Companion.toKotlin(args0)
                    })
                }),
                state = javaType.state(),
                taskType = javaType.taskType(),
            )
    }
}
